/* REGINA.H */

#ifndef    __REGINA.H
#define    __REGINA.H

#define MAX_AREA             64
#define MAX_DATE             20
#define MAX_DOMAIN           16
#define MAX_FROM             36
#define MAX_PASS             8
#define MAX_SUBJ             72
#define MAX_TO               36

#pragma pack(1)

typedef struct _ADR {
  USHORT            Zone;
  USHORT            Net;
  USHORT            Node;
  USHORT            Point;
} ADR, *PADR;

typedef struct _LINK {
  ADR               Adr;               /* Link address                        */
  CHAR              Domain[MAX_DOMAIN];/* Domain                              */
  CHAR              SysName[MAX_TO];   /* SysOp's name                        */
  CHAR              ABox[_MAX_PATH];   /* Path to alternate Box               */
  CHAR              TRL[_MAX_PATH];    /* The name of transit-request file    */
  CHAR              PPass[MAX_PASS];   /* Password for packet's header.
                                          Can be NOT NULL-terminated.         */
  CHAR              APass[MAX_PASS];   /* Password for our areafix.
                                          Can be NOT NULL-terminated.         */
  UCHAR             flags;             /* 1 - check PPASS
                                          2 - DON'T generate PPASS
                                          4 - Allow AutoCreate
                                          8 - Passive
                                          10- Sort SB
                                          20- Use Alternate Box
                                          40- DON'T Use LB
                                          80- DON'T Use EchoSplitter          */
  UCHAR             fl1;               /* 1 - Is uplink for T.R.
                                          2 - Can make T.R.
                                          4 - Send St.Age
  USHORT            AccLvl;            /* Link's access level                 */
  SHORT             AKA;               /* Our AKA to use with this link       */
  SHORT             CrGr;              /* Autocreate defaults from which group*/
  LONG              Psz;               /* Split packets with size >=Psz bytes */
  LONG              Arch;              /* Use archiver N; -1 - no packing     */
  LONG              Bsz;               /* Split bundles with size >=Bsz bytes */
  CHAR              flv;               /* Flavor:  0-hold
                                                   1-normal
                                                   2-direct
                                                   3-crash
                                                   4-immed                    */
  UCHAR             Rsrv1;
  USHORT            AOMTU;             /* Age of old mail to passive link     */
  UCHAR             TRPrio;            /* Priority of T.R. uplink             */
  ULONG             DayOfPause;        /* Day when link was PAUSEd            */
  UCHAR             Rsrv;
} LINK, *PLINK;

typedef struct _TRAF {
  ULONG             TM;               /* Messages                             */
  ULONG             TB;               /* Bytes                                */
  ULONG             TU;               /* UUE                                  */
} TRAF, *PTRAF;

typedef struct _ACS {
  USHORT            l;
  UCHAR             m;                /* 1-linked
                                         2-acc.dnd
                                         4-r/o                                */
} ACS, *PACS;

typedef struct _ECHO {
  CHAR              Area[MAX_AREA];   /* EchoArea name                        */
  CHAR              FName[_MAX_PATH]; /* FileBase name                        */
  CHAR              Comment[80];      /* Area comment                         */
  USHORT            RLvl;             /* Access level, needed to read echo    */
  USHORT            WLvl;             /* Access level, needed to write echo   */
  UCHAR             flags;            /* 1 - NOT passthrough
                                         2 - do NOT store SEEN-BY
                                         4 - invisible, if unreachable
                                         8 - mandatory
                                        10 - %RESCAN disabled
                                        20 - unlink enabled
                                        40 - do NOT store PATH
                                        80 - Squish; 0 - JAM                  */
  UCHAR             fl1;              /* 1 - Local
                                         2 - Local Echo; 0 - Local NetMail
                                         4 - Do NOT link echo with link plugin
                                        80 - Echo is in PAUSED state          */
  USHORT            PurgeN;           /* Purge if more than N messages        */
  USHORT            PurgeD;           /*Purge if received more than N days ago*/
  SHORT             Group;            /* Area is a member of the group N      */
  SHORT             AKA;              /* Our AKA to use when processing       */
  UCHAR             Rsrv0[4];
  TRAF              traf[7];          /* Traffic counters                     */
  time_t            st2;              /* time, when T.R.-echo was unlinked    */
  SHORT             dead;             /* Dead for %d Days                     */
  USHORT            UD;               /* Unlink if has no traffic for N days  */
  USHORT            NLinks;           /* Number of links                      */
  ACS               *Links;           /* Links addresses (first - uplink      */
  UCHAR             Rsrv;
} ECHO, *PECHO;

typedef struct _GR_LNK {
  UINT              n:14;             /* link number                          */
  UINT              a:2;              /* access:
                                         0-normal linked,
                                         1-acc.dnd,
                                         2-r/o Linked,
                                         3-r/o NOT linked                     */
} GR_LNK, *PGR_LNK;

typedef struct _GROUP {
  CHAR              FName[_MAX_PATH]; /* FileBase name                        */
  CHAR              Comment[80];      /* Area comment                         */
  USHORT            RLvl;             /* Access level, needed to read echo    */
  USHORT            WLvl;             /* Access level, needed to write echo   */
  UCHAR             flags;            /* 1 - NOT passthrough
                                         2 - do Not store SEEN-BY & PATH
                                         4 - invisible, if unreachable
                                         8 - mandatory
                                        10 - %RESCAN disabled
                                        20 - unlink enabled
                                        40 - do NOT store PATH
                                        80 - Squish; 0 - JAM                  */
  UCHAR             fl1;              /* 4 - Do NOT link echo with link plugin*/
  USHORT            PurgeN;           /* Purge if more than N messages        */
  USHORT            PurgeD;           /*Purge if received more than N days ago*/
  SHORT             AKA;              /* Our AKA to use when processing       */
  USHORT            UD;               /* Unlink if has no traffic for N days  */
  USHORT            NAccs;            /* Number of links                      */
  USHORT            NLinks;           /* Number of links                      */
  USHORT            *Accs;            /* Link's permissions                   */
  GR_LNK            *Links;           /* Links addresses (first - uplink)     */
} GROUP, *PGROUP;

typedef struct _SYS {
  CHAR              InbSec[_MAX_PATH]; /* Secured Inbound                     */
  CHAR              InbUns[_MAX_PATH]; /* Unprotected Inbound                 */
  CHAR              Outb[_MAX_PATH];   /* Outbound                            */
  CHAR              OutbT[_MAX_PATH];  /* Temp Outbound                       */
  CHAR              TossDir[_MAX_PATH];/* Temp Inbound                        */
  CHAR              NetMail[_MAX_PATH];/* Netmail directory                   */
  CHAR              MsgBase[_MAX_PATH];/* Default MessageBase path            */
  CHAR              TLog[_MAX_PATH];   /* Tosser log                          */
  CHAR              ALog[_MAX_PATH];   /* Areafix log                         */
  CHAR              SysName[MAX_TO];   /* SysOp's Name                        */
  CHAR              EchoList[32];      /* Filename, containing tossed echos   */
  CHAR              LBP[_MAX_PATH];    /* Base path to longBoxes              */
  CHAR              Domain[MAX_DOMAIN];/* Domain name, to be used with LB     */
  CHAR              Transit[_MAX_PATH];/* Path to transit-requests listings   */
  CHAR              LBFormat[32];      /* LongBoxes format                    */
  CHAR              LBSO[_MAX_PATH];   /* Long BSO                            */
  UCHAR             Prio;              /* Priority+1, 0=no change             */
  UCHAR             Flgs;              /* 1 - no response to RRQ,
                                          2 - do NOT use precise dupe checker
                                          4 - Show archiver when unpacking
                                          8 - check NETMAIL dupes
                                         10 - rescan DISABLED globally
                                         20 - %list sorted by groups
                                         40 - case sensitive password check
                                         80 - Use shortnames for autocreate   */
  UCHAR             Flags1;            /* 1 - create EchoList
                                          2 - do NOT log message summary
                                          4 - log echos summary
                                          8 - log links summary
                                         10 - show packing archiver
                                         20 - don't store dupes
                                         40 - kill areafix requests
                                         80 -Disable transit-requests GLOBALLY*/
  UCHAR             Flags2;            /* 1 - Fast MessageBase
                                          2 - Use Domain outbound
                                          4 - Remember bundles extension
                                          8 - Do NOT pause echos
                                         10 - Do NOT process netmails         */
  LONG              NDup;              /* How many dupe records to keep       */
  USHORT            KillTR;            /* Unlinked T.R. echo should be killed
                                          after than many hours               */
  UCHAR             Rsrv1;
  UCHAR             FDMBF_IFS_TimingScheme; /* Fast messagebase level         */
  LONG              Reporter;          /* Post reports into this echo, if >=0 */
  USHORT            stamp;             /* Day of last run                     */
  UCHAR             Rsrv2[2];
} SYS, *PSYS;

typedef struct _ARCH {
  ULONG             nonpacked;         /* Statistics, collecting by "pack"    */
  ULONG             packed;            /*  plug-in, and used to interpolate   */
  ULONG             TimeWorked;        /*  compress ratio                     */
  LONG              offset;            /* Sig.offset. Negative counts from EOF*/
  UCHAR             prio;              /* Priority+1; 0=No change             */
  CHAR              Name[8];           /* Short name of the archiver          */
  CHAR              sig[32];           /* Signature [n]=byte, [n+1]=check?    */
  CHAR              pack[80];          /* Command-line to pack                */
  CHAR              unpack[80];        /* Command-line to UnPack              */
} ARCH, *PARCH;

typedef struct _CARB {
  UCHAR          type;         /* 1 - case sensitive
                                  2 - grep
                                  4 - Common Masks
                                  80- Resendable                              */
  UCHAR          field;        /* 1 - From Name
                                  2 - To Name
                                  4 - Subj
                                  8 - From Address
                                  10- To Address
                                  20- Use sfrom filter                        */
  LONG           echo;         /* Where to store                              */
  LONG           sfrom;        /* Search in echo N only                       */
  CHAR           str[128];     /* Search-info                                 */
} CARB, *PCARB;

typedef struct _EXCL {
  ULONG          key;
  LONG           echo;
  LONG           link;
  LONG           value;
} EXCL, *PEXCL;

typedef struct _CFG {
  PSYS           Sys;          /* System information                          */
  ULONG          NAdr;         /* Number of our AKAs                          */
  PADR           Adr;          /* Our Addresses                               */
  ULONG          NLink;        /* Number of our links                         */
  PLINK          Link;         /* Our links                                   */
  ULONG          NEcho;        /* Number of echos                             */
  PECHO          Echo;         /* Echos                                       */
  ULONG          NGrp;         /* Nubmer of groups                            */
  PGROUP         Grp;          /* Groups                                      */
  ULONG          NArch;        /* Nubmer of archivers                         */
  PARCH          Arch;         /* Archivators definitions                     */
  ULONG          NCarb;        /* Nubmer of carbones                          */
  PCARB          Carb;         /* Carbon definitions                          */
  ULONG          NEx;          /* Number of EXes                              */
  PEXCL          Ex;           /* EXes                                        */
} CFG, *PCFG;

typedef struct _MSG_HDR {
  USHORT                     node_from;
  USHORT                     node_to;
  USHORT                     net_from;
  USHORT                     net_to;
  USHORT                     attr;
  USHORT                     cost;
  CHAR                       date[20];
} MSG_HDR, *PMSG_HDR;

typedef struct _JAM_KLUDGE {         /* Required for storing message in
                                        jam/squish format.                    */
  ULONG             off;             /* Offset from beginning of MSG          */
  LONG              len;             /* Length of kludge-line                 */
} JAM_KLUDGE, *PJAM_KLUDGE;

typedef struct _SBY {
  USHORT            net;
  USHORT            node;
} SBY, *PSBY;

typedef struct _MG {
  MSG_HDR           hdr;
  CHAR              from[MAX_FROM], to[MAX_TO], subj[MAX_SUBJ];
  CHAR              area[MAX_AREA];
  ULONG             MsgSize;                           /* Size of the message */
  CHAR              *Msg;                               /* Pointer to message */
  ULONG             NSB;                                /* number of SEEN-BYs */
  union             {
    PSBY              SB;                                         /* SEEN-BYs */
    PCHAR             SBt;                                        /* SEEN-BYs */
  };
  ULONG             NP;                                     /* number of PATH */
  union             {
    PSBY              PATH;                                           /* PATH */
    PCHAR             PATHt;                                          /* PATH */
  };
  CHAR              rsrv[12];
  LONG              ne;                                        /* echo number */
  LONG              nl;                                       /* our AKA "TO" */
  LONG              nf;                                    /* out link "FROM" */
  ULONG             Flags;                                        /* Flags-mask:
                                           0x00000001 - resendable CC
                                           0x00000002 - came from scan
                                           0x00000004 - Do not create SB && path
                                           0x00000008 - came from rescan
                                           0x00000010 - Store as BADmail
                                           0x00000020 - security succ. passed
                                           0x00000040 - came from tossbad
                                           0x80000000 - SB&path are text      */
  PJAM_KLUDGE       kldg;         /* kludges-list. required for storing message
                                     in JAM/SQUISH format. Message MUST begin
                                     from kldg[0], everything before it will be
                                     ignored                                  */
  LONG              Nkldg;                               /* number of kludges */
  CHAR              *msgid;       /* Pointer to msgid, or NULL if not present */
  CHAR              *reply;       /* Pointer to reply, or NULL if not present */
  CHAR              *pid;         /* Pointer to pid,   or NULL if not present */
  CHAR              *flags;       /* Pointer to flags, or NULL if not present */
  CHAR              *intl;        /* Pointer to intl,  or NULL if not present */
  CHAR              *fmpt;        /* Pointer to fmpt,  or NULL if not present */
  CHAR              *topt;        /* Pointer to topt,  or NULL if not present */
  CHAR              FidoAddr[256];       /* Fido address from msgid or origin */
  PADR              PAdrF, PAdrT;                  /* Packet security from/to */
} MG, *PMG;

typedef struct _MSG {
  CHAR              from[MAX_FROM], to[MAX_TO];
  CHAR              subj[MAX_SUBJ], date[MAX_DATE];
  USHORT            times_read;
  USHORT            dest_node, orig_node;
  USHORT            cost;
  USHORT            orig_net, dest_net;
  CHAR              res[8];
  USHORT            reply;
  USHORT            attrib;
  USHORT            next_reply;
} MSG, *PMSG;

typedef struct _MSG2 {
  MSG               msg;
  CHAR              *p;                            /* Pointer to message body */
  LONG              u;                                        /* Message size */
  CHAR              rsrv[8];
} MSG2, *PMSG2;

APIRET APIENTRY Configure(PCFG cfg, BOOL *SaveConf, ULONG argc, char *argv[]);
/* 室  䨣.  頥 譨   ૥.
  *SaveConf - 室   TRUE, ⮡ ᫥ 室  䨣
  ᭮  ࠭ 䨣. argc/argv - ࠬ, ।
  ᭮                                                             */

APIRET APIENTRY Entry(PCFG cfg, ULONG argc, char *argv[]);
/* 室  .  頥 譨   ૥.
   argc/argv - ࠬ, । ᭮                          */

APIRET ReadCFG(CHAR *FileName, BOOL NoConsole);
/* ⠥ 䨣. FileName -  䨣樮 䠩
  ᫨ NoConsole==TRUE,   砥 訡  ⨪  ࠭
  뢮  㤥                                                         */

APIRET WriteCFG(CHAR *FileName, BOOL NoConsole);
/* 뢠 䨣. FileName -  䨣樮 䠩
  ᫨ NoConsole==TRUE,   砥 訡  ⨪  ࠭
  뢮  㤥                                                         */

VOID FreeCFG(VOID);
/* ᢮  䨣樥 .                                 */

VOID SaveLog(ULONG flags, const char *form, ...);
/* 뢠 ப    樮쭮 뢠   ᮫.
  flags:                                                                      */
#define  LOG_AF     0x00000002 /* ᯮ짮 ॠ䨪-                   */
#define  LOG_VS     0x00000001 /* 뢠 뢮 ப  ᮫      */

LONG FindEcho(CHAR *area);
/*    䨣樨. area -   (    孨
 ॣ. 頥   CFG->ECHO[_n_]  -1, ᫨  
                                                                       */

VOID SortEchos(VOID);
/*    䨣樨. ⠥ !                           */

VOID AddEcho(LONG echo, CHAR *name);
/*   䨣 . echo -   CFG->ECHO,  
     饭  䨣. ஢ઠ 㭨쭮  !
  name -   ,     孨 ॣ(DosMapCase()).
  echo   ,  ᯮ짮 砩(  । 0-CFG->NECHO),
  ⮣ ᫥ 믮 AddEcho 室 뢠 SortEchos. ᯮ짮
   㪠, ࠡ  ᨭ , ⠬    
  ᯮ짮 AutoCreate()!                                                */

LONG AddEchoFast(CHAR *name);
/*   䨣 . name -   ,     
  孨 ॣ(DosMapCase()). 頥   ஬  뫠 饭
   䨣  -1, ᫨ ⠪  㦅 . ⫨砥  AddEcho ⥬,
    ॡ 뢠 ᫥ ᥡ SortEchos(),  祬 
   ந室 ⭮ ॥. ᯮ짮  㪠, ࠡ 
  ᨭ , ⠬     ᯮ짮 AutoCreate()!  */

VOID DelEcho(LONG echo);
/*    䨣樨. echo -   CFG->ECHO.
  । 맮 室 ஢ ࡮(CFG->CARB), ⮡   
  뢠   ! ᯮ짮  㪠, ࠡ  ᨭ
  饭!                                                                  */

VOID GiveName(CHAR *p, LONG e);
/*   ᠤ-  . p - 㪠⥫ 㤠  ,
  e -  .  頥                                      */

VOID ExportGED(SHORT zi, BOOL CommandLine);
/*  Areas.GED 䠩. zi ᥣ   ࠢ 0, CommandLine ᥣ
    TRUE                                                            */

ULONG GetTraf(PECHO pe, LONG mode);
/* 頥  䨪. pe - 㪠⥫  㦭 . mode = 0/1/2
  롨ࠥ  祭  ᠣ/ꥬ/                        */

LONG FindLink(LONG echo, LONG link);
/*  稪 . echo -   CFG->ECHO, link - 
   CFG->LINK. 頥  CFG->ECHO.Links[_n_],  -1 ᫨ 
   .                                                                  */

VOID RmvSB(ULONG echo, LONG link);
/*    ᪨  . echo -   CFG->ECHO,
  link -     ᪥   CFG->ECHO.Links[_n_];       */

VOID PutSB(ULONG echo, LONG NS, LONG link);
/* 頥     . echo -   CFG->ECHO,
  link -   CFG->LINK, NS -   ࠢ -1 ᫨
  -㭫,  0 ᫨  - . ஢ઠ 㭨쭮 
  ந.  ᪥    ⮬᪨ ॢ
    㭫.                                                         */

LONG JAMInit(VOID);
/* 樠 message-base . ᫥ 맮  짮 ஬
  㭪権 ࠡ  ᠦ-.  㪠, ࠡ  ᨭ, 뢠
   ,  ᠬ⥫  - . ᫥ , ᫥ ࠡ⪨
   易⥫쭮   맢 JAMTerm()                            */

VOID JAMTerm(VOID);
/* 樠 message-base , ᢮ ᯮ짮訥 
   */

VOID StoreMsg(PMG mg, LONG e2);
/* 頥 ᠣ  ଠ PMG  JAM  SQUISH .   
  mg->ne. e2   -1, ᫨ e2>=0,   쬮 㤥 饭 
  ^AREA:<area e2>. ᯮ짮 ࠧ襭  ६ ᨭ.   ६
  ᨭ । ᯮ짮 㦭 뢠 JAMInit();  ᯮ짮
  뢠 㪨 HOOK_BEFORE_STORE_MSG/HOOK_AFTER_STORE_MSG                  */

UCHAR HasAccess(LONG echo, LONG link);
/* 頥   link   echo:
    80=%RESCAN disabled;
    40=Mandatory;
    20=Linked;
    10=Not Found;
     8=Not ehough level;
     4=Denied by sysop;
     2=Has No Access to the group;
     1=R/O;                                                                   */

HEV *DUPEBefore(PVOID EXEAdr, ULONG *correct);
/*  । 㯮ࠡ稪  樠  㯮ࠡ稪.
  ᫨ 頥 NULL, , 樠 뫠 ᯥ譠. ᯮ짮 
  ६ ᨭ 饭. ᫥ 맮   ࠡ   
  맢 DUPEAfter()                                                          */

VOID DUPEAfter(VOID);
/* 뢠(᫨ 室) 㯮  䠩, ᢮ 
  㯮ࠡ稪 , 蠥 । 㯮ࠡ稪                    */

BOOL CheckDupe(PMG mg);
/*  㯮 ᠣ, ஢  稥  㯮, ᫨ 
  , . 頥 TRUE-ᠣ , FALSE-ᠣ  .
   ᯮ짮  ६ ᨭ  ᫥ 맮 DUPEBefore(). 
  맮  ᠣ   । mg->msgid, mg->subj, mg->area,
  mg->from, mg->to, mg->hdr.date.                                             */

LONG AutoCreate(CHAR *echo, PMG mg, LONG link, ULONG AutoLink);
/*  ᮧ   ६ ᨭ. echo -  ,  
    孨 ॣ. link - ,   ᮧ . Autolink
    ࠢ 1, ⮡  ᮧ  ࠡ⠫ ⮯᪠ 
  ᫥ ᢮ 㯯. ᫨ AutoLink=0,  ⠥ ᮧ १
  ࠭ , ⮯᪠  ࠡ뢠   ᮧ
  passthrough+autounlink. 頥 ,    뫠 饭 
  䨣. ᫨ mg!=NULL,  ᮮ⢥⢥  mg->ne                 */

VOID AddToMsg(PMSG2 msg, LONG link, LONG aka, CHAR *txt, LONG l);
/*   뫮.   ᮮ饭 msg ப txt. l -  ப
   0, ᫨  ப ⭠. ᫨ ᮮ饭  ⢮
  (msg->p==NULL),   㤥 ᮧ,  ⮬ 쬮 ᮧ ⠪:
    ᫨ link>=0,  쬮 ᮧ  襣  aka   ᮯ
    襩 ⥬   link  areafix-,  ᠡ  areafix-஫
    ⮣ .  ⮬, ᫨  link ⠭  0x40000000
    (link|=0x40000000),  쬮 ᮧ ४⭮,  NPD-譮.
    ᫨ link<0,  쬮 ᮧ      ᮯ 襩
    ⥬,  main aka  main aka.
  ᫨ ᮮ饭 㦅 ⢮(msg->p!=NULL),  ப   
  쬠, link  aka  ᯮ.
  ப  饬 砥   \x00, ⮬    txt 㤥
   \x0D                                                            */

VOID AddToMsg2(PMSG2 msg, LONG link, LONG aka, const CHAR *form, ... ) {
/*  筠 AddToMsg(),  ⥬ ᪫祭,   txt  l ᯮe
  ଠ஢ 뢮,  sprintf().                               */

APIRET MSGWriteOurMsg(MSG2 *msg);
  /* 뢠 ⬠-ᮮ饭, ᮧ   AddToMsg*(). 
  쬠  ᢮,    㦭 ᢮ ᠬ
  (free(msg->p))                                                              */


/*
  騥 砭.
᮪   䨣樨   ஢    ⠭.
᮪    ஢    ⠭.
᮪ 稪 /㯯   ஢   ᮮ⢥饩
    ⠭. ᪫祭 -   _ᥣ_   ,
  ..    =CFG->ECHO[n].Links[0].l
 ᨬ  ஢ 䨣஬, ⮡  
 樨, ਬ, ⮡  ACS   ⢮
६ 䫠 "᫨"  " 饭",  ,  
䫠  , ⮡  ACS.m  뫠 ࠢ .   Links->m 
 ࠢ 1,  㣮 祭 ⠥ 訡.

    䨣:
  EXE-譨   ⠥ 䨣,  ।  䨣樮 .
 䨣   RGAPI ,  ।⠢塞 RGAPI 㭪樨
  ࠡ. ࠭ 䨣    , 맢 WriteCFG,
 ⠭  室 *SaveConf=TRUE. ᫥  ࠢ EXE-譨,
 ᢮   䨣樥  蠥 ࠡ,  
⢥ ૥ 祭 饭 䨣஬(Configure).
᢮ 䨣(FreeCFG)  ६ ࠡ 䨣 , ᫨ ⮫쪮
  ᮡࠫ  䨣  (ReadCFG)!

  ⠩.
   ࠡ  㫥 ,   ࠭⠩  FDMBF.DLL.
⮬  ଠ쭮 ࠡ 㭪権 RGAPI.DLL 䨣 
ᯮ짮 -ࠩ  㭪樨 ࠡ   १ FDMBF, 
 ஡, ⮬  FDMBF ᯮ ᢮  ,  ᫨ 
ணࠬ ᠬ  ᮪ ,  FDMBF  ᬮ  ᢮ 
.

  H 㪠  ⮬ 䠩 ⮢ 祭  童  뢠騥 ⨯
rsrv H H H H !                                             */

void *  APIENTRY  Malloc         ( size_t );
void *  APIENTRY  MallocH        ( size_t );
void    APIENTRY  Free           ( void * );
void *  APIENTRY  Realloc        ( void *, size_t );
void *  APIENTRY  Calloc         ( size_t, size_t );
void *  APIENTRY  CallocH        ( size_t, size_t );
char *  APIENTRY  Strdup         ( char * );

#endif

/*
definitions file

LIBRARY REGINA INITINSTANCE TERMINSTANCE

DESCRIPTION 'Regina-Tosser/2 v0.05b by Alexander Kryzhanovsky, 2:460/111@FidoNet'

PROTMODE
STACKSIZE 16384

DATA MULTIPLE NONSHARED
EXPORTS
  Configure                  @1972  noname
  Entry                      @1972  noname

IMPORTS
  ReadCFG          =         RGAPI.1
  WriteCFG         =         RGAPI.2
  FreeCFG          =         RGAPI.3
  SaveLog          =         RGAPI.5
  FindEcho         =         RGAPI.6
  CFGfAPI          =         RGAPI.8
  SortEchos        =         RGAPI.9
  AddEcho          =         RGAPI.10
  HasAccess        =         RGAPI.11
  RmvSB            =         RGAPI.16
  PutSB            =         RGAPI.17
  MSGWriteOurMsg   =         RGAPI.35
  ExportGED        =         RGAPI.39
  GetTraf          =         RGAPI.42
  GiveName         =         RGAPI.43
  FindLink         =         RGAPI.45
  DelEcho          =         RGAPI.46
  AddToMsg         =         RGAPI.54
  AutoCreate       =         RGAPI.56
  AddToMsg2        =         RGAPI.59
  DUPEBefore       =         RGAPI.61
  DUPEAfter        =         RGAPI.62
  CheckDupe        =         RGAPI.85
  AddEchoFast      =         RGAPI.86
  StoreMsg         =         RGAPI.87
  JAMInit          =         RGAPI.88
  JAMTerm          =         RGAPI.89

  MallocH          =         FDMBF.7001  ;allocates memory above 512M limit
  CallocH          =         FDMBF.7005  ;allocates memory above 512M limit

  Malloc           =         FDMBF.9003
  Free             =         FDMBF.9004
  Realloc          =         FDMBF.9021
  Strdup           =         FDMBF.9051
  Calloc           =         FDMBF.9072
*/