/*
   Programm     RGNOLINK.CMD
   Owner        2:5085/1@FIDOnet.org, Sergey Popov
   Date         17.07.2000
   Comment      This programm checks temporary "dead" points with Regina's config
                and post message to SysOp
   Creator      S. Popov (2:5085/1.41 AKA 2:5085/1.104)
   Note         This program uses Regina-Toser/2's Rexx Functions and
                starts as "Regina Hand REXX RgNolink <file>" where:
                <file> - optional param with filename to which report
                will be writed, otherwise report will be writed to
                RgNolink.txt in directory from which this script was executed
*/
/*trace ?AR*/

  /* Initializing */
  If RxFuncQuery( 'SysLoadFuncs' ) \= 0 Then
    Do
      Call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
      Call SysLoadFuncs
    End /* If RxFuncQuery */

  Parse Upper Arg ThisArg
  Parse Source . . ThisProg
  Call SysCls
  Call SysCurState 'OFF'

  ThisPath  = FileSpec('D', thisProg) || FileSpec('P', thisProg)

  Mark.WhiteOnBlue  = '1B'x || '[37;44m'
  Mark.WhiteOnBlack = '1B'x || '[0m'
  Mark.WhiteOnGreen = '1B'x || '[37;42m'
  Mark.WhiteOnRed   = '1B'x || '[37;41m'
  Mark.GreenOnBlack = '1B'x || '[32;40m'
  Mark.RedOnBlack   = '1B'x || '[31;40m'

  Sentence = Mark.GreenOnBlack || ' RgRexx plug-in - RgNolink, b02 (c) 2:5085/1, 2000' || Mark.WhiteOnBlack
  rc = SayIn(0, 2, Sentence)
  Sentence = Mark.GreenOnBlack || ' for Regina-Tosser/2 (c) Alexander Kryzhanovsky 2:460/111' || Mark.WhiteOnBlack
  rc = SayIn(1, 2, Sentence)

  If RgLinkGetNumber() \= 0 Then
    Do
      Sentence = 'Checking ->'
      rc = SayIn(5, 2, Sentence)

      counter = 0
      Do i = 1 To RgLinkGetNumber()
        Call SysCurPos 4, 0
        Say Center(Copies('', 60), 80, ' ')
        Call SysCurPos 16, 0
        Say Center(Copies('', 60), 80, ' ')

        Sentence = RgLinkPtrToStr(i) RgLinkGetName(i) || '1B'x || '[K'
        rc = SayIn(5, 13, Sentence)
        Select
          When RgLinkGetPassive(i) = 0 Then /* Link is't in "Passive Mode" */
            Do
              If LinkEchos(i) \= 0 Then
                Do
                  Sentence = RgLinkPtrToStr(i) 'Checked! Good link.' || '1B'x || '[K'
                  rc = SayIn(5, 13, Sentence)
                End
              Else
                Do                          /* Link is linked to no one echo(s) */
                  Sentence = RgLinkPtrToStr(i) 'Checked! NOT active link.' || '1B'x || '[K'
                  rc = SayIn(5, 13, Sentence)
                  counter = counter + 1
                  DeadLink.0 = counter
                  DeadLink.counter = RgLinkPtrToStr(i)
                End
            End
          When RgLinkGetPassive(i) = 1 Then /* Link is in "Passive Mode"   */
            Do
              Sentence = RgLinkPtrToStr(i) 'Checked! *DEAD* since' RgLinkGetDayOfPause(i) || '1B'x || '[K'
              rc = SayIn(5, 13, Sentence)
              counter = counter + 1
              DeadLink.0 = counter
              DeadLink.counter = RgLinkPtrToStr(i) || '!' || RgLinkGetDayOfPause(i)
            End
          OtherWise
        End
        rc = Scroll(5, 15)
      End
    End
  Else
    Do
      Sentence = Mark.RedOnBlack || 'Your system has no one links. Nothing todo.' || Mark.WhiteOnBlack
      rc = SayIn(5, 2, Sentence)
      Call SysSleep 3
      Exit -1
    End

  Do i = 5 To 15
    Call SysCurPos i, 0
    Say '1B'x || '[K'
  End
  Call SysCurPos 9, 0
  Say Mark.GreenOnBlack || Center('Your system was successefully tested', 80, ' ')
  Say Mark.WhiteOnBlack

  Call SysCurPos 11, 0
  Say Mark.GreenOnBlack || Center('Creating report, wait...', 80, ' ')
  Say Mark.WhiteOnBlack

  If DataType(DeadLink.0) = 'NUM' Then
    Do i = 1 To DeadLink.0
      Parse Value DeadLink.i With PointAddr '@' Domain '!' DeadDate
      AddrLen = strip(Length(PointAddr))
      If DataType(Left(DeadDate, 2), 'N') = 1 Then
        RepLine.i = PointAddr Copies('.', 45 - AddrLen) '*DEAD* since' DeadDate
      Else
        RepLine.i = PointAddr Copies('.', 45 - AddrLen) '/NOT active/'
    End
  Else
    Do
       DeadLink.0 = 0
       RepLine.1  = "Congratulation! Your station haven't got %PAUSED link(s)!"
    End

  If ThisArg = '' Then
    RepName = ThisPath || 'RgNolink.Txt'
  Else
    RepName = ThisArg
  Call SysFileDelete RepName
/*================================ MAIN REPORT =======================================*/
  /* Here is HEADER */
  Sentence = ''
  Call WriteLineToFile RepName, Sentence
  Sentence = 'Following is a list of all links and their %PAUSED state:'
  Call WriteLineToFile RepName, Sentence
  Sentence = ''
  Call WriteLineToFile RepName, Sentence

  /* Here is REPORT */
  If DeadLink.0 \= 0 Then
    Do i = 1 To DeadLink.0
      Call WriteLineToFile RepName, RepLine.i
    End
  Else Call WriteLineToFile RepName, RepLine.1

  /* Here is FOOTER */
  Sentence = ''
  Call WriteLineToFile RepName, Sentence
  Sentence = "We've got" RgLinkGetNumber() 'link(s), from which' DeadLink.0 'temporary %PAUSED'
  Call WriteLineToFile RepName, Sentence
  Sentence = ' These include :'
  Call WriteLineToFile RepName, Sentence
  Sentence = ' *DEAD*       - temporary paused by Regina-Tosser/2'
  Call WriteLineToFile RepName, Sentence
  Sentence = ' /NOT active/ - linked to no one echo(s)'
  Call WriteLineToFile RepName, Sentence

  Sentence = ''
  Call WriteLineToFile RepName, Sentence
  Sentence = ' Report created by "RgNolink REXX plug-in" for Regina Tosser/2 (c)'
  Call WriteLineToFile RepName, Sentence
  Sentence = ' Started at' Time() Date()
  Call WriteLineToFile RepName, Sentence
/*================================ END OF MAIN REPORT ================================*/

/*=================================== MSG TO SYSOP ===================================*/
/* You could REM it for some reason or change for your desire */
  SysopMSG.header.from        = 'Regina-Tosser/2'
  SysopMSG.header.to          = RgSysGetSysopName()
  SysopMSG.header.subj        = 'Links status report:'
  SysopMSG.header.fromaddress = RgAdrPtrToStr(1)
  SysopMSG.header.toaddress   = RgAdrPtrToStr(1)
  counter = 0
  Do While Lines(RepName) \= 0
    counter = counter + 1
    SysopMSG.text.counter = LineIn(RepName)
  End
  SysopMSG.text.0 = counter

  rc = RgCreateMessage('SysopMSG')
/*================================ END OF MSG TO SYSOP ===============================*/

  Call SysCls
  Call SysCurPos 1, 0
  Say Mark.GreenOnBlack || Center('Ooh, good job. Done!', 80, ' ')
  Say Mark.WhiteOnBlack

  Call SysSleep 1
Exit 0

/********************************* Functions **********************************/

SayIn: Procedure
  /* Arguments: Ypos, Xpos, Sentence */
  Call SysCurPos Arg(1), Arg(2)
  Say Arg(3)
Return 0


FileExist: Procedure
  Arg Name
  Rc = SysFileTree(Name, 'FileName', 'FO')
  If FileName.0 = 0 Then
    CompleteCode = 'N'
  Else
    CompleteCode = 'Y'
Return CompleteCode


WriteLineToFile: Procedure
  /* Arguments: FileName, Sentence */
  Do While Stream(Arg(1), 'c', 'Open Write') \= 'READY:'
    Call SysSleep 1
  End
  Call Stream  Arg(1),'c', 'Close'

  Call Stream  Arg(1),'c', 'Seek <0'
  Call LineOut Arg(1), Arg(2)
  Call Stream  Arg(1),'c', 'Close'
Return

Scroll: Procedure
  /*
    ! 楤 뢠 ப ࠭ 稭  5  19
     뢮   ࠭  ᬥ饭 ப +1  ⪮ 5- ப
    (஫)
  */
  Arg BegStr, EndStr

  Line.1 = SysTextScreenRead(BegStr, 13, 66)
  Do i = 2 To EndStr - BegStr
    Line.i = SysTextScreenRead(BegStr + i - 1, 13, 66)
  End

  Call SysCurPos BegStr, 13
  Say '1B'x || '[K'
  Do i = 1 To EndStr - BegStr
    Call SysCurPos (BegStr + i), 13
    Say Line.i
  End
Return 0

LinkEchos: Procedure
  /*
    楤 頥 ⢮ ,  
    祭  (), ।  ࠬ
  */
  Arg LinkNum

  LinkEchos = 0
  If RgEchoGetNumber() \= 0 Then
    Do i = 1 To RgEchoGetNumber()
      rc = RgEchoGetLinks(i, 'Links')
      If Links.0 \= 0 Then
        Do k = 1 To Links.0
          If Word(Links.k, 1) = LinkNum Then
            Do
              LinkEchos = LinkEchos + 1
              Leave k
            End
        End
    End
Return LinkEchos
